@@ -25,6 +25,11 @@ def resolve_address(address):
     return ip
 
 
+@sio.on("designate")
+async def designate(virtual_ip):
+    print(f"Virtual address: {virtual_ip}")
+
+
 @sio.on("connect")
 async def on_connect():
     print("connected to server")
